/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// global header of the "dart" module

#ifndef DART_H
#define DART_H

#if defined(WIN32)
#ifdef dart_EXPORTS
#define DART_API __declspec(dllexport)
#else
#define DART_API __declspec(dllimport)
#endif
#else
#define DART_API
#endif

#include "tbox.h"

/**
 * @brief Namespace for dart module
 */
namespace dart
{
// Problem and B.C. handling
class Problem;
class Fluid;
class Body;
class Assign;
class Initial;
class Dirichlet;
class Freestream;
class Wake;
class WakeElement;
class Kutta;
class KuttaElement;
class Blowing;

// Formulation
class PotentialResidual;
class FreestreamResidual;
class WakeResidual;
class KuttaResidual;
class BlowingResidual;
class LoadFunctional;

// Solver
class Solver;
class Picard;
class Newton;
class FpeLSFunction;
class Adjoint;

// General
class F0Ps;
class F0El;
class F0ElC;
class F0ElSpeedSound;
class F0ElRho;
class F0ElRhoClamp;
class F0ElRhoLin;
class F0ElMach;
class F0ElMachClamp;
class F0ElMachLin;
class F0ElCp;
class F0ElCpClamp;
class F0ElCpLin;
class F1El;
class F1ElVi;
class F1Ct;
class F1CtDrag;
class F1CtSide;
class F1CtLift;
class Face;
class FaceEq;

} // namespace dart

#endif //DART_H
